Tokio.rs reexports to prevent tokio dependencies within external code
Structs
- Receiver
- Receive values from the associated
UnboundedSender. - Send
Error - Error returned by the
Sender. - Sender
- Send values to the associated
UnboundedReceiver.
Functions
- channel
- Creates an unbounded mpsc channel for communicating between asynchronous tasks without backpressure.