Module oneshot

Tokio.rs reexports to prevent tokio dependencies within external code

Structs

Receiver
Receives a value from the associated Sender.
Sender
Sends a value to the associated Receiver.

Functions

channel
Creates a new one-shot channel for sending single values across asynchronous tasks.