Module oneshot

Module oneshot 

non-async replacement for oneshot channels

Structs

Receiver
The receiving half of Rust’s channel (or sync_channel) type. This half can only be owned by one thread.
Sender
The sending-half of Rust’s asynchronous channel type.

Enums

RecvTimeoutError
This enumeration is the list of possible errors that made recv_timeout unable to return data when called. This can occur with both a channel and a sync_channel.

Functions

channel
Creates a new asynchronous channel, returning the sender/receiver halves.