spawned_
rt
0.1.3
Module oneshot
Module Items
Structs
Functions
In spawned_
rt::
tasks
spawned_rt
::
tasks
Module
oneshot
Tokio.rs reexports to prevent tokio dependencies within external code
Structs

Receiver
Receives a value from the associated
Sender
.
Sender
Sends a value to the associated
Receiver
.
Functions

channel
Creates a new one-shot channel for sending single values across asynchronous tasks.