IO-threads based module to support shared behavior with task based version.
Modules
Structs
- Cancellation
Token - A token that can be used to signal cancellation.
- Join
Handle - An owned permission to join on a thread (block on its termination).
Traits
Functions
- block_
on - Create a temporary tokio runtime and block on the given future.
- ctrl_c
- Returns a closure that blocks until Ctrl+C is received.
- run
- Initialize tracing and run the given function.
- sleep
- Puts the current thread to sleep for at least the specified amount of time.
- spawn
- Spawns a new thread, returning a
JoinHandlefor it. - spawn_
blocking - Spawn blocking is the same as spawn for pure threaded usage.