IO-threads based module to support shared behavior with task based version.
Modules
Structs
- Cancellation
Token - Join
Handle - An owned permission to join on a thread (block on its termination).
Traits
Functions
- block_
on - run
- sleep
- Puts the current thread to sleep for at least the specified amount of time.
- spawn
- Spawns a new thread, returning a
JoinHandlefor it. - spawn_
blocking - Spawn blocking is the same as spawn for pure threaded usage.