non-async replacement for oneshot channels
Structs
- Receiver
- The receiving half of Rust’s
channel(orsync_channel) type. This half can only be owned by one thread. - Sender
- The sending-half of Rust’s asynchronous
channeltype.
Enums
- Recv
Timeout Error - This enumeration is the list of possible errors that made
recv_timeoutunable to return data when called. This can occur with both achanneland async_channel.
Functions
- channel
- Creates a new asynchronous channel, returning the sender/receiver halves.